import os
import siliconcompiler


root = os.path.dirname(__file__) + "../../"

topmodule = "la_iopadring"
chip = siliconcompiler.Chip(topmodule)
chip.load_target('skywater130_demo')

chip.set('input', 'verilog', f'{root}/padring/rtl/la_iopadring.v')
chip.add('option', 'ydir', f'{root}/padring/rtl/')
chip.add('option', 'ydir',  f'{root}/submodules/openpdks/pdks/sky130/libs/sky130io/lambda')
chip.add('option', 'ydir',  f'{root}/submodules/openpdks/pdks/sky130/libs/sky130io/bb')
chip.set('option', 'relax', True)
chip.set('option', 'steplist', ['import', 'syn', 'floorplan'])
chip.set('asic', 'diearea', [(0, 0), (2000, 2000)])
chip.run()



import siliconcompiler
import os


########################
# SiliconCompiler Setup
########################
def setup(target=None):
    '''Lambdalib Padring Setup'''

    # Create chip object
    chip = siliconcompiler.Chip('la_iopadring')

    # Project sources
    root = os.path.dirname(__file__)
    chip.add('input', 'verilog', f"{root}/rtl/la_iopadring.v")
    chip.add('input', 'verilog', f"{root}/rtl/la_ioside.v")
    chip.add('option', 'idir', f"{root}/rtl")

    return chip



from siliconcompiler import Chip

from lambdalib import lambdalib


def test_setup_without_depencency():
    chip = Chip('<lib>')
    chip.use(lambdalib)

    assert 'la_stdlib' in chip.getkeys('library')

    assert len(chip.get('library', 'la_stdlib', 'option', 'ydir')) == 1


def test_setup_with_depencency():
    chip = Chip('<lib>')
    chip.use(lambdalib)

    assert 'la_stdlib' in chip.getkeys('library')
    assert 'la_iolib' in chip.getkeys('library')
    assert 'la_ramlib' in chip.getkeys('library')

    assert len(chip.get('library', 'la_iolib', 'option', 'ydir')) == 2
    assert len(chip.get('library', 'la_ramlib', 'option', 'ydir')) == 2



from lambdalib import register_data_source
from siliconcompiler import Library


########################
# SiliconCompiler Setup
########################
def setup(chip):
    '''Lambdalib library setup script'''

    dependencies = {
        'iolib': ['stdlib'],
        'stdlib': [],
        'ramlib': ['stdlib'],
        'padring': ['stdlib'],
        'syslib': ['stdlib'],
        'vectorlib': ['stdlib']
    }

    # Project sources
    register_data_source(chip)

    libs = []
    # Iterate over all libs
    for name, dep in dependencies.items():
        lib = Library(chip, f'la_{name}', package='lambdalib')

        for path in [name, *dep]:
            lib.add('option', 'ydir', f"lambdalib/{path}/rtl")
            lib.add('option', 'idir', f"lambdalib/{path}/rtl")

        libs.append(lib)

    return libs



import glob
import siliconcompiler
from siliconcompiler.flows import lintflow


def setup(chip, path=None):

    files = glob.glob('rtl/*.v')
    for item in files:
        chip.input(item)


if __name__ == "__main__":

    design = "la_inv"
    chip = siliconcompiler.Chip(design)

    # local files
    setup(chip)

    # run lint
    chip.use(lintflow)
    chip.set('option', 'mode', 'sim')
    chip.set('option', 'flow', 'lintflow')
    chip.run()
    # run synthesis

    # run verifiation
